# coding: utf-8

"""
    ICA Rest API

    This API can be used to interact with Illumina Connected Analytics.<br> <h2>Authentication</h2> <p> Authentication to the  API can be done in multiple ways:<br> <ul><li>For the entire API, except for the POST /tokens endpoint: API-key + JWT</li> <li>Only for the POST /tokens endpoint: API-key + Basic Authentication</li></ul> </p> <p> <h4>API-key</h4> API keys are managed within the Illumina portal where you can manage your profile after you have logged on. The API-key has to be provided in the X-API-Key header parameter when executing API calls to ICA. In the background, a JWT will be requested at the IDP of Illumina to create a session. A good practice is to not use the API-key for every API call, but to first generate a JWT and to use that for authentication in subsequent calls.<br> </p> <p> <h4>JWT</h4> To avoid using an API-key for each call, we recommend to request a JWT via the POST /tokens endpoint  using this API-key. The JWT will expire after a pre-configured period specified by a tenant administrator through the IAM console in the Illumina portal. The JWT is the preferred way for authentication.<br>A not yet expired, still valid JWT could be refreshed using the POST /tokens:refresh endpoint.<br>Refreshing the JWT is not possible if the JWT was generated by using an API-key.<br> </p> <p> <h4>Basic Authentication</h4> Basic authentication is only supported by the POST /tokens endpoint for generating a JWT. Use \"Basic base64encoded(emailaddress:password)\" in the \"Authorization\" header parameter for this authentication method. In case having access to multiple tenants using the same email-address, also provide the \"tenant\" request parameter to indicate what tenant you would like to request a JWT for. </p> <p> <h2>Compression</h2> If the API client provides request header 'Accept-Encoding' with value 'gzip', then the API applies GZIP compression on the JSON response. This significantly reduces the size and thus the download time of the response, which results in faster end-to-end API calls. In case of compression, the API also provides response header 'Content-Encoding' with value 'gzip', as indication for the client that decompression is required. </p> 

    The version of the OpenAPI document: 3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from libica.openapi.v3.models.analysis_output_mapping import AnalysisOutputMapping
from libica.openapi.v3.models.create_analysis_tag import CreateAnalysisTag
from libica.openapi.v3.models.nextflow_json_analysis_input import NextflowJsonAnalysisInput
from typing import Optional, Set
from typing_extensions import Self

class CreateNextflowJsonAnalysis(BaseModel):
    """
    CreateNextflowJsonAnalysis
    """ # noqa: E501
    user_reference: Annotated[str, Field(min_length=1, strict=True, max_length=255)] = Field(description="The user-reference of the analysis. This should be something meaningful for the user.", alias="userReference")
    pipeline_id: StrictStr = Field(description="The pipeline for which an analysis will be created.", alias="pipelineId")
    tags: Optional[CreateAnalysisTag] = None
    analysis_storage_id: Optional[StrictStr] = Field(default=None, description="The id of the storage to use for the analysis.", alias="analysisStorageId")
    output_parent_folder_id: Optional[StrictStr] = Field(default=None, description="The id or the urn of the folder in which the output folder should be created.", alias="outputParentFolderId")
    analysis_output: Optional[List[Optional[AnalysisOutputMapping]]] = Field(default=None, alias="analysisOutput")
    input_form_values: NextflowJsonAnalysisInput = Field(alias="inputFormValues")
    __properties: ClassVar[List[str]] = ["userReference", "pipelineId", "tags", "analysisStorageId", "outputParentFolderId", "analysisOutput", "inputFormValues"]

    @field_validator('user_reference')
    def user_reference_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[a-zA-Z0-9 _-]*(\/[a-zA-Z0-9 _-]+)*$", value):
            raise ValueError(r"must validate the regular expression /^[a-zA-Z0-9 _-]*(\/[a-zA-Z0-9 _-]+)*$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CreateNextflowJsonAnalysis from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of tags
        if self.tags:
            _dict['tags'] = self.tags.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in analysis_output (list)
        _items = []
        if self.analysis_output:
            for _item_analysis_output in self.analysis_output:
                if _item_analysis_output:
                    _items.append(_item_analysis_output.to_dict())
            _dict['analysisOutput'] = _items
        # override the default output from pydantic by calling `to_dict()` of input_form_values
        if self.input_form_values:
            _dict['inputFormValues'] = self.input_form_values.to_dict()
        # set to None if analysis_storage_id (nullable) is None
        # and model_fields_set contains the field
        if self.analysis_storage_id is None and "analysis_storage_id" in self.model_fields_set:
            _dict['analysisStorageId'] = None

        # set to None if output_parent_folder_id (nullable) is None
        # and model_fields_set contains the field
        if self.output_parent_folder_id is None and "output_parent_folder_id" in self.model_fields_set:
            _dict['outputParentFolderId'] = None

        # set to None if analysis_output (nullable) is None
        # and model_fields_set contains the field
        if self.analysis_output is None and "analysis_output" in self.model_fields_set:
            _dict['analysisOutput'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CreateNextflowJsonAnalysis from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "userReference": obj.get("userReference"),
            "pipelineId": obj.get("pipelineId"),
            "tags": CreateAnalysisTag.from_dict(obj["tags"]) if obj.get("tags") is not None else None,
            "analysisStorageId": obj.get("analysisStorageId"),
            "outputParentFolderId": obj.get("outputParentFolderId"),
            "analysisOutput": [AnalysisOutputMapping.from_dict(_item) for _item in obj["analysisOutput"]] if obj.get("analysisOutput") is not None else None,
            "inputFormValues": NextflowJsonAnalysisInput.from_dict(obj["inputFormValues"]) if obj.get("inputFormValues") is not None else None
        })
        return _obj


