# coding: utf-8

"""
    ICA Rest API

    This API can be used to interact with Illumina Connected Analytics.<br> <h2>Authentication</h2> <p> Authentication to the  API can be done in multiple ways:<br> <ul><li>For the entire API, except for the POST /tokens endpoint: API-key + JWT</li> <li>Only for the POST /tokens endpoint: API-key + Basic Authentication</li></ul> </p> <p> <h4>API-key</h4> API keys are managed within the Illumina portal where you can manage your profile after you have logged on. The API-key has to be provided in the X-API-Key header parameter when executing API calls to ICA. In the background, a JWT will be requested at the IDP of Illumina to create a session. A good practice is to not use the API-key for every API call, but to first generate a JWT and to use that for authentication in subsequent calls.<br> </p> <p> <h4>JWT</h4> To avoid using an API-key for each call, we recommend to request a JWT via the POST /tokens endpoint  using this API-key. The JWT will expire after a pre-configured period specified by a tenant administrator through the IAM console in the Illumina portal. The JWT is the preferred way for authentication.<br>A not yet expired, still valid JWT could be refreshed using the POST /tokens:refresh endpoint.<br>Refreshing the JWT is not possible if the JWT was generated by using an API-key.<br> </p> <p> <h4>Basic Authentication</h4> Basic authentication is only supported by the POST /tokens endpoint for generating a JWT. Use \"Basic base64encoded(emailaddress:password)\" in the \"Authorization\" header parameter for this authentication method. In case having access to multiple tenants using the same email-address, also provide the \"tenant\" request parameter to indicate what tenant you would like to request a JWT for. </p> <p> <h2>Compression</h2> If the API client provides request header 'Accept-Encoding' with value 'gzip', then the API applies GZIP compression on the JSON response. This significantly reduces the size and thus the download time of the response, which results in faster end-to-end API calls. In case of compression, the API also provides response header 'Content-Encoding' with value 'gzip', as indication for the client that decompression is required. </p> 

    The version of the OpenAPI document: 3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from libica.openapi.v3.models.bench_settings import BenchSettings
from libica.openapi.v3.models.external_docker_image_settings import ExternalDockerImageSettings
from libica.openapi.v3.models.internal_docker_image_settings import InternalDockerImageSettings
from libica.openapi.v3.models.tenant_identifier import TenantIdentifier
from libica.openapi.v3.models.user_identifier import UserIdentifier
from typing import Optional, Set
from typing_extensions import Self

class DockerImage(BaseModel):
    """
    DockerImage
    """ # noqa: E501
    id: StrictStr
    time_created: datetime = Field(alias="timeCreated")
    time_modified: datetime = Field(alias="timeModified")
    owner: UserIdentifier
    tenant: TenantIdentifier
    name: StrictStr
    version: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    status: StrictStr
    type: StrictStr
    internal_docker_image_settings: Optional[InternalDockerImageSettings] = Field(default=None, alias="internalDockerImageSettings")
    external_docker_image_settings: Optional[ExternalDockerImageSettings] = Field(default=None, alias="externalDockerImageSettings")
    bench_settings: Optional[BenchSettings] = Field(default=None, alias="benchSettings")
    __properties: ClassVar[List[str]] = ["id", "timeCreated", "timeModified", "owner", "tenant", "name", "version", "description", "status", "type", "internalDockerImageSettings", "externalDockerImageSettings", "benchSettings"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['PARTIAL', 'AVAILABLE', 'DELETED', 'BUILDFAILED', 'DELETING']):
            raise ValueError("must be one of enum values ('PARTIAL', 'AVAILABLE', 'DELETED', 'BUILDFAILED', 'DELETING')")
        return value

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['TOOL', 'BENCH']):
            raise ValueError("must be one of enum values ('TOOL', 'BENCH')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DockerImage from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict['owner'] = self.owner.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tenant
        if self.tenant:
            _dict['tenant'] = self.tenant.to_dict()
        # override the default output from pydantic by calling `to_dict()` of internal_docker_image_settings
        if self.internal_docker_image_settings:
            _dict['internalDockerImageSettings'] = self.internal_docker_image_settings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of external_docker_image_settings
        if self.external_docker_image_settings:
            _dict['externalDockerImageSettings'] = self.external_docker_image_settings.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bench_settings
        if self.bench_settings:
            _dict['benchSettings'] = self.bench_settings.to_dict()
        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict['version'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if internal_docker_image_settings (nullable) is None
        # and model_fields_set contains the field
        if self.internal_docker_image_settings is None and "internal_docker_image_settings" in self.model_fields_set:
            _dict['internalDockerImageSettings'] = None

        # set to None if external_docker_image_settings (nullable) is None
        # and model_fields_set contains the field
        if self.external_docker_image_settings is None and "external_docker_image_settings" in self.model_fields_set:
            _dict['externalDockerImageSettings'] = None

        # set to None if bench_settings (nullable) is None
        # and model_fields_set contains the field
        if self.bench_settings is None and "bench_settings" in self.model_fields_set:
            _dict['benchSettings'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DockerImage from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "timeCreated": obj.get("timeCreated"),
            "timeModified": obj.get("timeModified"),
            "owner": UserIdentifier.from_dict(obj["owner"]) if obj.get("owner") is not None else None,
            "tenant": TenantIdentifier.from_dict(obj["tenant"]) if obj.get("tenant") is not None else None,
            "name": obj.get("name"),
            "version": obj.get("version"),
            "description": obj.get("description"),
            "status": obj.get("status"),
            "type": obj.get("type"),
            "internalDockerImageSettings": InternalDockerImageSettings.from_dict(obj["internalDockerImageSettings"]) if obj.get("internalDockerImageSettings") is not None else None,
            "externalDockerImageSettings": ExternalDockerImageSettings.from_dict(obj["externalDockerImageSettings"]) if obj.get("externalDockerImageSettings") is not None else None,
            "benchSettings": BenchSettings.from_dict(obj["benchSettings"]) if obj.get("benchSettings") is not None else None
        })
        return _obj


