# coding: utf-8

"""
    ICA Rest API

    This API can be used to interact with Illumina Connected Analytics.<br> <h2>Authentication</h2> <p> Authentication to the  API can be done in multiple ways:<br> <ul><li>For the entire API, except for the POST /tokens endpoint: API-key + JWT</li> <li>Only for the POST /tokens endpoint: API-key + Basic Authentication</li></ul> </p> <p> <h4>API-key</h4> API keys are managed within the Illumina portal where you can manage your profile after you have logged on. The API-key has to be provided in the X-API-Key header parameter when executing API calls to ICA. In the background, a JWT will be requested at the IDP of Illumina to create a session. A good practice is to not use the API-key for every API call, but to first generate a JWT and to use that for authentication in subsequent calls.<br> </p> <p> <h4>JWT</h4> To avoid using an API-key for each call, we recommend to request a JWT via the POST /tokens endpoint  using this API-key. The JWT will expire after a pre-configured period specified by a tenant administrator through the IAM console in the Illumina portal. The JWT is the preferred way for authentication.<br>A not yet expired, still valid JWT could be refreshed using the POST /tokens:refresh endpoint.<br>Refreshing the JWT is not possible if the JWT was generated by using an API-key.<br> </p> <p> <h4>Basic Authentication</h4> Basic authentication is only supported by the POST /tokens endpoint for generating a JWT. Use \"Basic base64encoded(emailaddress:password)\" in the \"Authorization\" header parameter for this authentication method. In case having access to multiple tenants using the same email-address, also provide the \"tenant\" request parameter to indicate what tenant you would like to request a JWT for. </p> <p> <h2>Compression</h2> If the API client provides request header 'Accept-Encoding' with value 'gzip', then the API applies GZIP compression on the JSON response. This significantly reduces the size and thus the download time of the response, which results in faster end-to-end API calls. In case of compression, the API also provides response header 'Content-Encoding' with value 'gzip', as indication for the client that decompression is required. </p> 

    The version of the OpenAPI document: 3
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from libica.openapi.v3.models.analysis_storage_v4 import AnalysisStorageV4
from libica.openapi.v3.models.pipeline_language_version import PipelineLanguageVersion
from libica.openapi.v3.models.pipeline_report_config import PipelineReportConfig
from libica.openapi.v3.models.pipeline_tag import PipelineTag
from libica.openapi.v3.models.tenant_identifier import TenantIdentifier
from libica.openapi.v3.models.user_identifier import UserIdentifier
from typing import Optional, Set
from typing_extensions import Self

class PipelineV4(BaseModel):
    """
    PipelineV4
    """ # noqa: E501
    id: StrictStr
    urn: Optional[Annotated[str, Field(min_length=1, strict=True, max_length=2000)]] = Field(default=None, description="The URN of the pipeline. The format is urn:ilmn:ica:\\<type of the object\\>:\\<ID of the object\\>#\\<optional human readable hint representing the object\\>. The hint can be omitted, in that case the hashtag (#) must also be omitted.")
    time_created: datetime = Field(alias="timeCreated")
    time_modified: datetime = Field(alias="timeModified")
    owner: UserIdentifier
    tenant: TenantIdentifier
    code: Annotated[str, Field(min_length=1, strict=True, max_length=255)] = Field(description="The code of the pipeline")
    description: Annotated[str, Field(min_length=1, strict=True, max_length=4000)] = Field(description="The description of the pipeline")
    status: Optional[StrictStr] = Field(default=None, description="The status of the pipeline")
    language: StrictStr = Field(description="The language that is used by the pipeline")
    language_version: Optional[PipelineLanguageVersion] = Field(default=None, alias="languageVersion")
    pipeline_tags: PipelineTag = Field(alias="pipelineTags")
    analysis_storage: AnalysisStorageV4 = Field(alias="analysisStorage")
    proprietary: Optional[StrictBool] = Field(default=False, description="A boolean which indicates if the code of this pipeline is proprietary")
    input_form_type: Optional[StrictStr] = Field(default=None, description="The type of the inputform used.", alias="inputFormType")
    report_configs: Optional[PipelineReportConfig] = Field(default=None, alias="reportConfigs")
    __properties: ClassVar[List[str]] = ["id", "urn", "timeCreated", "timeModified", "owner", "tenant", "code", "description", "status", "language", "languageVersion", "pipelineTags", "analysisStorage", "proprietary", "inputFormType", "reportConfigs"]

    @field_validator('status')
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['DRAFT', 'RELEASED']):
            raise ValueError("must be one of enum values ('DRAFT', 'RELEASED')")
        return value

    @field_validator('language')
    def language_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['CWL', 'NEXTFLOW', 'UNKNOWN']):
            raise ValueError("must be one of enum values ('CWL', 'NEXTFLOW', 'UNKNOWN')")
        return value

    @field_validator('input_form_type')
    def input_form_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['XML', 'JSON']):
            raise ValueError("must be one of enum values ('XML', 'JSON')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PipelineV4 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict['owner'] = self.owner.to_dict()
        # override the default output from pydantic by calling `to_dict()` of tenant
        if self.tenant:
            _dict['tenant'] = self.tenant.to_dict()
        # override the default output from pydantic by calling `to_dict()` of language_version
        if self.language_version:
            _dict['languageVersion'] = self.language_version.to_dict()
        # override the default output from pydantic by calling `to_dict()` of pipeline_tags
        if self.pipeline_tags:
            _dict['pipelineTags'] = self.pipeline_tags.to_dict()
        # override the default output from pydantic by calling `to_dict()` of analysis_storage
        if self.analysis_storage:
            _dict['analysisStorage'] = self.analysis_storage.to_dict()
        # override the default output from pydantic by calling `to_dict()` of report_configs
        if self.report_configs:
            _dict['reportConfigs'] = self.report_configs.to_dict()
        # set to None if urn (nullable) is None
        # and model_fields_set contains the field
        if self.urn is None and "urn" in self.model_fields_set:
            _dict['urn'] = None

        # set to None if status (nullable) is None
        # and model_fields_set contains the field
        if self.status is None and "status" in self.model_fields_set:
            _dict['status'] = None

        # set to None if language_version (nullable) is None
        # and model_fields_set contains the field
        if self.language_version is None and "language_version" in self.model_fields_set:
            _dict['languageVersion'] = None

        # set to None if proprietary (nullable) is None
        # and model_fields_set contains the field
        if self.proprietary is None and "proprietary" in self.model_fields_set:
            _dict['proprietary'] = None

        # set to None if report_configs (nullable) is None
        # and model_fields_set contains the field
        if self.report_configs is None and "report_configs" in self.model_fields_set:
            _dict['reportConfigs'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PipelineV4 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "urn": obj.get("urn"),
            "timeCreated": obj.get("timeCreated"),
            "timeModified": obj.get("timeModified"),
            "owner": UserIdentifier.from_dict(obj["owner"]) if obj.get("owner") is not None else None,
            "tenant": TenantIdentifier.from_dict(obj["tenant"]) if obj.get("tenant") is not None else None,
            "code": obj.get("code"),
            "description": obj.get("description"),
            "status": obj.get("status"),
            "language": obj.get("language"),
            "languageVersion": PipelineLanguageVersion.from_dict(obj["languageVersion"]) if obj.get("languageVersion") is not None else None,
            "pipelineTags": PipelineTag.from_dict(obj["pipelineTags"]) if obj.get("pipelineTags") is not None else None,
            "analysisStorage": AnalysisStorageV4.from_dict(obj["analysisStorage"]) if obj.get("analysisStorage") is not None else None,
            "proprietary": obj.get("proprietary") if obj.get("proprietary") is not None else False,
            "inputFormType": obj.get("inputFormType"),
            "reportConfigs": PipelineReportConfig.from_dict(obj["reportConfigs"]) if obj.get("reportConfigs") is not None else None
        })
        return _obj


